"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var data_speed_avg_1 = require("../data/data.speed-avg");
var data_pace_avg_1 = require("../data/data.pace-avg");
var data_swim_pace_avg_1 = require("../data/data.swim-pace-avg");
var data_pace_1 = require("../data/data.pace");
var data_speed_1 = require("../data/data.speed");
var data_swim_pace_1 = require("../data/data.swim-pace");
var data_vertical_speed_avg_1 = require("../data/data.vertical-speed-avg");
var ActivityTypesHelper = /** @class */ (function () {
    function ActivityTypesHelper() {
    }
    ActivityTypesHelper.getActivityTypesAsUniqueArray = function () {
        return Array.from(new Set(Object.keys(ActivityTypes).reduce(function (array, key) {
            array.push(ActivityTypes[key]); // Important get the key via the enum else it will be chaos
            return array;
        }, []))).sort(function (left, right) {
            if (left < right) {
                return -1;
            }
            if (left > right) {
                return 1;
            }
            return 0;
        });
    };
    ActivityTypesHelper.averageSpeedDerivedMetricsToUseForActivityType = function (activityType) {
        switch (activityType) {
            case ActivityTypes.Running:
                return [data_pace_avg_1.DataPaceAvg.type];
            case ActivityTypes['Trail Running']:
                return [data_pace_avg_1.DataPaceAvg.type, data_vertical_speed_avg_1.DataVerticalSpeedAvg.type];
            case ActivityTypes.Treadmill:
            case ActivityTypes['Track and Field']:
            case ActivityTypes['Elliptical trainer']:
                return [data_pace_avg_1.DataPaceAvg.type];
            case ActivityTypes.Swimming:
            case ActivityTypes['Open Water Swimming']:
            case ActivityTypes.swimming_lap_swimming:
                return [data_speed_avg_1.DataSpeedAvg.type, data_swim_pace_avg_1.DataSwimPaceAvg.type];
            default:
                return [data_speed_avg_1.DataSpeedAvg.type];
        }
    };
    ActivityTypesHelper.speedDerivedMetricsToUseForActivityType = function (activityType) {
        switch (activityType) {
            case ActivityTypes.Running:
            case ActivityTypes['Trail Running']:
            case ActivityTypes.Treadmill:
            case ActivityTypes['Track and Field']:
            case ActivityTypes['Elliptical trainer']:
                return [data_pace_1.DataPace.type];
            case ActivityTypes.Swimming:
            case ActivityTypes['Open Water Swimming']:
            case ActivityTypes.swimming_lap_swimming:
                return [data_speed_1.DataSpeed.type, data_swim_pace_1.DataSwimPace.type];
            default:
                return [data_speed_1.DataSpeed.type];
        }
    };
    return ActivityTypesHelper;
}());
exports.ActivityTypesHelper = ActivityTypesHelper;
/**
 * This enum works like a all matchers for normalized sport types between different naming across services
 */
var ActivityTypes;
(function (ActivityTypes) {
    ActivityTypes["unknown"] = "Unknown sport";
    ActivityTypes["Unknown sport"] = "Unknown sport";
    ActivityTypes["undefined"] = "Unknown sport";
    ActivityTypes["generic"] = "Generic";
    ActivityTypes["Generic"] = "Generic";
    ActivityTypes["transition"] = "Transition";
    ActivityTypes["Transition"] = "Transition";
    ActivityTypes["fitness_equipment"] = "Fitness Equipment";
    ActivityTypes["Fitness Equipment"] = "Fitness Equipment";
    ActivityTypes["Not specified sport"] = "Unknown sport";
    ActivityTypes["Other"] = "Unknown sport";
    ActivityTypes["Multisport"] = "Multisport";
    ActivityTypes["multisport"] = "Multisport";
    ActivityTypes["running_virtual_activity"] = "Running";
    ActivityTypes["Run"] = "Running";
    ActivityTypes["run"] = "Running";
    ActivityTypes["running_track"] = "Running";
    ActivityTypes["running_trail"] = "Trail Running";
    ActivityTypes["Running"] = "Running";
    ActivityTypes["running"] = "Running";
    ActivityTypes["Cycling"] = "Cycling";
    ActivityTypes["cycling"] = "Cycling";
    ActivityTypes["cycling_road"] = "Cycling";
    ActivityTypes["cycling_track_cycling"] = "Cycling";
    ActivityTypes["cycling_gravel_cycling"] = "Cycling";
    ActivityTypes["Biking"] = "Cycling";
    ActivityTypes["biking"] = "Cycling";
    ActivityTypes["e_biking"] = "E Biking";
    ActivityTypes["E Biking"] = "E Biking";
    ActivityTypes["cycling_mountain"] = "Mountain biking";
    ActivityTypes["MountainBiking"] = "Mountain biking";
    ActivityTypes["Mountain Biking"] = "Mountain biking";
    ActivityTypes["cycling_cyclocross"] = "Mountain biking";
    ActivityTypes["mountain"] = "Mountain biking";
    ActivityTypes["Mountain biking"] = "Mountain biking";
    ActivityTypes["motorcycling"] = "Motorcycling";
    ActivityTypes["Motorcycling"] = "Motorcycling";
    ActivityTypes["boating"] = "Boating";
    ActivityTypes["Boating"] = "Boating";
    ActivityTypes["driving"] = "Driving";
    ActivityTypes["Driving"] = "Driving";
    ActivityTypes["Swimming"] = "Swimming";
    ActivityTypes["swimming"] = "Swimming";
    ActivityTypes["Swim"] = "Swimming";
    ActivityTypes["swim"] = "Swimming";
    ActivityTypes["basketball"] = "Basketball";
    ActivityTypes["soccer"] = "Soccer";
    ActivityTypes["american_football"] = "American Football";
    ActivityTypes["American footBall"] = "American Football";
    ActivityTypes["American Football"] = "American Football";
    ActivityTypes["Skating"] = "Skating";
    ActivityTypes["Aerobics"] = "Aerobics";
    ActivityTypes["YogaPilates"] = "YogaPilates";
    ActivityTypes["training_yoga"] = "Yoga";
    ActivityTypes["yoga"] = "Yoga";
    ActivityTypes["Yoga"] = "Yoga";
    ActivityTypes["Trekking"] = "Trekking";
    ActivityTypes["Walking"] = "Walking";
    ActivityTypes["walking"] = "Walking";
    ActivityTypes["Walk"] = "Walking";
    ActivityTypes["walk"] = "Walking";
    ActivityTypes["Sailing"] = "Sailing";
    ActivityTypes["sailing"] = "Sailing";
    ActivityTypes["Kayaking"] = "Kayaking";
    ActivityTypes["kayaking"] = "Kayaking";
    ActivityTypes["rafting"] = "Rafting";
    ActivityTypes["Rafting"] = "Rafting";
    ActivityTypes["rowing"] = "Rowing";
    ActivityTypes["Rowing"] = "Rowing";
    ActivityTypes["Climbing"] = "Climbing";
    ActivityTypes["cycling_indoor_cycling"] = "Indoor Cycling";
    ActivityTypes["Indoorcycling"] = "Indoor Cycling";
    ActivityTypes["indoor_cycling"] = "Indoor Cycling";
    ActivityTypes["Indoor cycling"] = "Indoor Cycling";
    ActivityTypes["Indoor Cycling"] = "Indoor Cycling";
    ActivityTypes["cycling_virtual_activity"] = "Indoor Cycling";
    ActivityTypes["Circuit training"] = "Circuit training";
    ActivityTypes["Triathlon"] = "Triathlon";
    ActivityTypes["Alpine skiing"] = "Alpine skiing";
    ActivityTypes["alpine_skiing"] = "Alpine skiing";
    ActivityTypes["alpine_skiing_downhill"] = "Alpine skiing";
    ActivityTypes["Backcountry skiing"] = "Backcountry Skiing";
    ActivityTypes["Backcountry Skiing"] = "Backcountry Skiing";
    ActivityTypes["cross_country_skiing_backcountry"] = "Backcountry Skiing";
    ActivityTypes["Snowboarding"] = "Snowboarding";
    ActivityTypes["snowboarding"] = "Snowboarding";
    ActivityTypes["running_street"] = "Running";
    ActivityTypes["running_road"] = "Running";
    ActivityTypes["Crosscountry skiing"] = "Crosscountry Skiing";
    ActivityTypes["Crosscountry Skiing"] = "Crosscountry Skiing";
    ActivityTypes["cross_country_skiing"] = "Crosscountry Skiing";
    ActivityTypes["backcountry"] = "Crosscountry Skiing";
    ActivityTypes["downhill"] = "Downhill skiing";
    ActivityTypes["Downhill skiing"] = "Downhill skiing";
    ActivityTypes["Weight training"] = "Weight training";
    ActivityTypes["Basketball"] = "Basketball";
    ActivityTypes["Soccer"] = "Soccer";
    ActivityTypes["Ice Hockey"] = "Ice Hockey";
    ActivityTypes["Volleyball"] = "Volleyball";
    ActivityTypes["Football"] = "Football";
    ActivityTypes["Softball"] = "Softball";
    ActivityTypes["Cheerleading"] = "Cheerleading";
    ActivityTypes["Baseball"] = "Baseball";
    ActivityTypes["tennis"] = "Tennis";
    ActivityTypes["Tennis"] = "Tennis";
    ActivityTypes["Badminton"] = "Badminton";
    ActivityTypes["Table tennis"] = "Table Tennis";
    ActivityTypes["Table Tennis"] = "Table Tennis";
    ActivityTypes["Racquet ball"] = "Racquet ball";
    ActivityTypes["Squash"] = "Squash";
    ActivityTypes["Combat sport"] = "Combat sport";
    ActivityTypes["Boxing"] = "Boxing";
    ActivityTypes["Floorball"] = "Floorball";
    ActivityTypes["Scuba diving"] = "Scuba Diving";
    ActivityTypes["Scuba Diving"] = "Scuba Diving";
    ActivityTypes["Free diving"] = "Free Diving";
    ActivityTypes["diving"] = "Diving";
    ActivityTypes["Diving"] = "Diving";
    ActivityTypes["diving_apnea_hunting"] = "Diving";
    ActivityTypes["Snorkeling"] = "Snorkeling";
    ActivityTypes["Swimrun"] = "Swimrun";
    ActivityTypes["Duathlon"] = "Duathlon";
    ActivityTypes["Aquathlon"] = "Aquathlon";
    ActivityTypes["Adventure Racing"] = "Adventure Racing";
    ActivityTypes["Bowling"] = "Bowling";
    ActivityTypes["Cricket"] = "Cricket";
    ActivityTypes["Crosstrainer"] = "Crosstrainer";
    ActivityTypes["Dancing"] = "Dancing";
    ActivityTypes["Golf"] = "Golf";
    ActivityTypes["golf"] = "Golf";
    ActivityTypes["hang_gliding"] = "Hang gliding";
    ActivityTypes["Hang gliding"] = "Hang gliding";
    ActivityTypes["horseback_riding"] = "Horseback Riding";
    ActivityTypes["Horseback Riding"] = "Horseback Riding";
    ActivityTypes["Gymnastics"] = "Gymnastics";
    ActivityTypes["Handball"] = "Handball";
    ActivityTypes["Horseback riding"] = "Horseback riding";
    ActivityTypes["Ice Skating"] = "Ice Skating";
    ActivityTypes["ice_skating"] = "Ice Skating";
    ActivityTypes["ice skating"] = "Ice Skating";
    ActivityTypes["Ice skating"] = "Ice Skating";
    ActivityTypes["fitness_equipment_indoor_rowing"] = "Indoor Rowing";
    ActivityTypes["Indoor Rowing"] = "Indoor Rowing";
    ActivityTypes["indoor_rowing"] = "Indoor Rowing";
    ActivityTypes["Canoeing"] = "Canoeing";
    ActivityTypes["Motorsports"] = "Motorsports";
    ActivityTypes["Mountaineering"] = "Mountaineering";
    ActivityTypes["mountaineering"] = "Mountaineering";
    ActivityTypes["Orienteering"] = "Orienteering";
    ActivityTypes["running_navigate"] = "Orienteering";
    ActivityTypes["Rugby"] = "Rugby";
    ActivityTypes["Ski Touring"] = "Ski Touring";
    ActivityTypes["Stretching"] = "Stretching";
    ActivityTypes["training_strength_training"] = "Strength Training";
    ActivityTypes["fitness_equipment_strength_training"] = "Strength Training";
    ActivityTypes["strength_training"] = "Strength Training";
    ActivityTypes["Strength training"] = "Strength Training";
    ActivityTypes["strength training"] = "Strength Training";
    ActivityTypes["Strength Training"] = "Strength Training";
    ActivityTypes["Telemark skiing"] = "Telemark skiing";
    ActivityTypes["Track and Field"] = "Track and Field";
    ActivityTypes["Trail Running"] = "Trail Running";
    ActivityTypes["Trail running"] = "Trail Running";
    ActivityTypes["trail_running"] = "Trail Running";
    ActivityTypes["trail"] = "Trail Running";
    ActivityTypes["swimming_open_water"] = "Open Water Swimming";
    ActivityTypes["swimming_lap_swimming"] = "Swimming";
    ActivityTypes["Open water swimming"] = "Open Water Swimming";
    ActivityTypes["open water swimming"] = "Open Water Swimming";
    ActivityTypes["Open Water Swimming"] = "Open Water Swimming";
    ActivityTypes["open_water"] = "Open Water Swimming";
    ActivityTypes["Nordic walking"] = "Nordic walking";
    ActivityTypes["Snow shoeing"] = "Snow shoeing";
    ActivityTypes["Windsurfing/Surfing"] = "Windsurfing";
    ActivityTypes["windsurfing"] = "Windsurfing";
    ActivityTypes["Windsurfing"] = "Windsurfing";
    ActivityTypes["Kettlebell"] = "Kettlebell";
    ActivityTypes["Roller skiing"] = "Roller skiing";
    ActivityTypes["paddling"] = "Paddling";
    ActivityTypes["Paddling"] = "Paddling";
    ActivityTypes["flying"] = "Flying";
    ActivityTypes["Flying"] = "Flying";
    ActivityTypes["Cross fit"] = "Cross fit";
    ActivityTypes["cross_fit"] = "Cross fit";
    ActivityTypes["Kitesurfing/Kiting"] = "Kitesurfing";
    ActivityTypes["kitesurfing"] = "Kitesurfing";
    ActivityTypes["Kitesurfing"] = "Kitesurfing";
    ActivityTypes["tactical"] = "Tactical";
    ActivityTypes["Tactical"] = "Tactical";
    ActivityTypes["jumpmaster"] = "Jumpmaster";
    ActivityTypes["Jumpmaster"] = "Jumpmaster";
    ActivityTypes["boxing"] = "Boxing";
    ActivityTypes["floor_climbing"] = "Floor Climbing";
    ActivityTypes["Floor climbing"] = "Floor Climbing";
    ActivityTypes["Floor Climbing"] = "Floor Climbing";
    ActivityTypes["Paragliding"] = "Paragliding";
    ActivityTypes["running_treadmill"] = "Treadmill";
    ActivityTypes["Treadmill"] = "Treadmill";
    ActivityTypes["treadmill"] = "Treadmill";
    ActivityTypes["Indoor running"] = "Indoor Running";
    ActivityTypes["Indoor Running"] = "Indoor Running";
    ActivityTypes["running_indoor"] = "Indoor Running";
    ActivityTypes["running_indoor_running"] = "Indoor Running";
    ActivityTypes["Frisbee"] = "Frisbee";
    ActivityTypes["Indoor training"] = "Indoor training";
    ActivityTypes["Hiking"] = "Hiking";
    ActivityTypes["hiking_trail"] = "Hiking";
    ActivityTypes["hiking"] = "Hiking";
    ActivityTypes["hike"] = "Hiking";
    ActivityTypes["Hike"] = "Hiking";
    ActivityTypes["Fishing"] = "Fishing";
    ActivityTypes["fishing"] = "Fishing";
    ActivityTypes["Hunting"] = "Hunting";
    ActivityTypes["hunting"] = "Hunting";
    ActivityTypes["route"] = "Route";
    ActivityTypes["Route"] = "Route";
    ActivityTypes["inline_skating"] = "Inline Skating";
    ActivityTypes["Inline Skating"] = "Inline Skating";
    ActivityTypes["Inline skating"] = "Inline Skating";
    ActivityTypes["rock_climbing"] = "Rock Climbing";
    ActivityTypes["Rock Climbing"] = "Rock Climbing";
    ActivityTypes["Rock climbing"] = "Rock Climbing";
    ActivityTypes["sky_diving"] = "Sky Diving";
    ActivityTypes["Sky Diving"] = "Sky Diving";
    ActivityTypes["Sky diving"] = "Sky Diving";
    ActivityTypes["sky diving"] = "Sky Diving";
    ActivityTypes["snowshoeing"] = "Snowshoeing";
    ActivityTypes["Snowshoeing"] = "Snowshoeing";
    ActivityTypes["snowmobiling"] = "Snowmobiling";
    ActivityTypes["Snowmobiling"] = "Snowmobiling";
    ActivityTypes["stand_up_paddleboarding"] = "Stand up paddling";
    ActivityTypes["Standup paddling (SUP)"] = "Stand up paddling";
    ActivityTypes["Stand up paddling"] = "Stand up paddling";
    ActivityTypes["stand up paddling"] = "Stand up paddling";
    ActivityTypes["Stand Up Paddling"] = "Stand up paddling";
    ActivityTypes["Stand up Paddling"] = "Stand up paddling";
    ActivityTypes["surfing"] = "Surfing";
    ActivityTypes["Surfing"] = "Surfing";
    ActivityTypes["wakeboarding"] = "Wakeboarding";
    ActivityTypes["Wakeboarding"] = "Wakeboarding";
    ActivityTypes["water_skiing"] = "Water skiing";
    ActivityTypes["Water skiing"] = "Water skiing";
    ActivityTypes["Water Skiing"] = "Water skiing";
    ActivityTypes["training_flexibility_training"] = "Flexibility Training";
    ActivityTypes["flexibility_training"] = "Flexibility Training";
    ActivityTypes["Flexibility Training"] = "Flexibility Training";
    ActivityTypes["training"] = "Training";
    ActivityTypes["Training"] = "Training";
    ActivityTypes["cardio_training"] = "Cardio Training";
    ActivityTypes["training_cardio_training"] = "Cardio Training";
    ActivityTypes["Cardio Training"] = "Cardio Training";
    ActivityTypes["fitness_equipment_elliptical"] = "Elliptical trainer";
    ActivityTypes["Elliptical trainer"] = "Elliptical trainer";
})(ActivityTypes = exports.ActivityTypes || (exports.ActivityTypes = {}));
