"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var helpers_1 = require("../events/utilities/helpers");
var data_store_1 = require("../data/data.store");
var Stream = /** @class */ (function () {
    function Stream(type, data) {
        this.data = [];
        this.type = type;
        if (data) {
            this.data = data;
        }
    }
    Stream.prototype.getData = function (onlyNumeric, filterInfinity) {
        var _this = this;
        if (onlyNumeric === void 0) { onlyNumeric = false; }
        if (filterInfinity === void 0) { filterInfinity = false; }
        if (!onlyNumeric && !filterInfinity) {
            return this.data;
        }
        return this.data.filter(function (dataItem) { return !_this.shouldDataBeFiltered(dataItem, onlyNumeric, filterInfinity); });
    };
    Stream.prototype.getDurationOfData = function (onlyNumeric, filterInfinity) {
        return this.getStreamDataByDuration(0, onlyNumeric, filterInfinity).map(function (data) { return data.time / 1000; });
    };
    Stream.prototype.setData = function (data) {
        this.data = data;
        return this;
    };
    Stream.prototype.getStreamDataByTime = function (startDate, onlyNumeric, filterInfinity) {
        var _this = this;
        if (onlyNumeric === void 0) { onlyNumeric = false; }
        if (filterInfinity === void 0) { filterInfinity = false; }
        return this.data.reduce(function (accu, dataItem, index) {
            if (_this.shouldDataBeFiltered(dataItem, onlyNumeric, filterInfinity)) {
                return accu;
            }
            accu.push({
                time: startDate.getTime() + index * 1000,
                value: dataItem,
            });
            return accu;
        }, []);
    };
    Stream.prototype.getStreamDataByDuration = function (offset, onlyNumeric, filterInfinity) {
        var _this = this;
        if (offset === void 0) { offset = 0; }
        if (onlyNumeric === void 0) { onlyNumeric = false; }
        if (filterInfinity === void 0) { filterInfinity = false; }
        return this.data.reduce(function (accu, dataItem, index) {
            if (_this.shouldDataBeFiltered(dataItem, onlyNumeric, filterInfinity)) {
                return accu;
            }
            accu.push({
                time: index * 1000 + (offset || 0),
                value: dataItem,
            });
            return accu;
        }, []);
    };
    Stream.prototype.isUnitDerivedDataType = function () {
        return data_store_1.DynamicDataLoader.isUnitDerivedDataType(this.type);
    };
    Stream.prototype.toJSON = function () {
        return {
            type: this.type,
            data: this.data,
        };
    };
    Stream.prototype.shouldDataBeFiltered = function (data, onlyNumeric, filterInfinity) {
        return (onlyNumeric && !helpers_1.isNumber(data)) || (filterInfinity && (data === Infinity || data === -Infinity));
    };
    return Stream;
}());
exports.Stream = Stream;
